tlslite.messages.ClientKeyExchange

Package tlslite :: Module messages :: Class ClientKeyExchange |
[hide private]
[frames] | no frames]

# Class ClientKeyExchange

source code

    HandshakeMsg --+
                   |
                  ClientKeyExchange

Instance Methods | [hide private]
__init__(self, cipherSuite, version=None) | source code
createDH(self, dh_Yc) | source code
createRSA(self, encryptedPreMasterSecret) | source code
createSRP(self, srp_A) | source code
parse(self, p) | source code
write(self) | source code
Inherited from `HandshakeMsg`: `postWrite`

Method Details | [hide private]

### __init__(self, cipherSuite, version=None) (Constructor) | source code
Overrides: HandshakeMsg.__init__